#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-handler-launch
version:              3.0.3.1
visibility:           public
id:                   wai-handler-launch-3.0.3.1-pjbRI03svqIWRDYVDLlYO
key:                  wai-handler-launch-3.0.3.1-pjbRI03svqIWRDYVDLlYO
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
synopsis:             Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.

category:             Web
abi:                  509bf8f18d8ea6b5dd46c67fa215a4cd
exposed:              True
exposed-modules:      Network.Wai.Handler.Launch
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-handler-launch-3.0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-handler-launch-3.0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-handler-launch-3.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-handler-launch
hs-libraries:         HSwai-handler-launch-3.0.3.1-pjbRI03svqIWRDYVDLlYO
depends:
    async-2.2.6-L49doqolqOiLsPy3OvdI1h base-4.18.2.1
    bytestring-0.11.5.3 http-types-0.12.4-BfnwqLIFvgHNb88uBZwW9
    process-1.6.19.0 streaming-commons-0.2.3.1-J3aACsbr7Bf4BJZCZqUImf
    transformers-0.6.1.0 wai-3.2.4-56REQg4dhfjHKYLZyIkMb9
    warp-3.4.0-Bz53tmaUOCu1sZfrie2t5U

haddock-interfaces:
    /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock

haddock-html:         /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

